@@ -12,7 +12,7 @@ fn sscanf_benchmark(c: &mut Criterion) {
     group.bench_function("sscanf i32", |b| {
         b.iter(|| {
             let mut first_number: i32 = 0;
-            black_box(sscanf!(input, "{}", first_number));
+            sscanf!(input, "{}", first_number);
             black_box(first_number);
         })
     });
@@ -21,7 +21,7 @@ fn sscanf_benchmark(c: &mut Criterion) {
     group.bench_function("sscanf i64", |b| {
         b.iter(|| {
             let mut first_number: i64 = 0;
-            black_box(sscanf!(input, "{}", first_number));
+            sscanf!(input, "{}", first_number);
             black_box(first_number);
         })
     });
@@ -30,7 +30,7 @@ fn sscanf_benchmark(c: &mut Criterion) {
     group.bench_function("sscanf u32", |b| {
         b.iter(|| {
             let mut first_number: u32 = 0;
-            black_box(sscanf!(input, "{}", first_number));
+            sscanf!(input, "{}", first_number);
             black_box(first_number);
         })
     });
@@ -39,7 +39,7 @@ fn sscanf_benchmark(c: &mut Criterion) {
     group.bench_function("sscanf u64", |b| {
         b.iter(|| {
             let mut first_number: u64 = 0;
-            black_box(sscanf!(input, "{}", first_number));
+            sscanf!(input, "{}", first_number);
             black_box(first_number);
         })
     });
@@ -48,7 +48,7 @@ fn sscanf_benchmark(c: &mut Criterion) {
     group.bench_function("sscanf f32", |b| {
         b.iter(|| {
             let mut first_number: f32 = 0.0;
-            black_box(sscanf!(input, "{}", first_number));
+            sscanf!(input, "{}", first_number);
             black_box(first_number);
         })
     });
@@ -57,7 +57,7 @@ fn sscanf_benchmark(c: &mut Criterion) {
     group.bench_function("sscanf f64", |b| {
         b.iter(|| {
             let mut first_number: f64 = 0.0;
-            black_box(sscanf!(input, "{}", first_number));
+            sscanf!(input, "{}", first_number);
             black_box(first_number);
         })
     });
@@ -66,7 +66,7 @@ fn sscanf_benchmark(c: &mut Criterion) {
     group.bench_function("sscanf string", |b| {
         b.iter(|| {
             let mut product: String = String::new();
-            black_box(sscanf!(input, "{}", product));
+            sscanf!(input, "{}", product);
             black_box(product);
         })
     });
@@ -75,7 +75,7 @@ fn sscanf_benchmark(c: &mut Criterion) {
     group.bench_function("sscanf string with brackets", |b| {
         b.iter(|| {
             let mut product: String = String::new();
-            black_box(sscanf!(input, "{}", product));
+            sscanf!(input, "{}", product);
             black_box(product);
         })
     });
@@ -84,7 +84,7 @@ fn sscanf_benchmark(c: &mut Criterion) {
     group.bench_function("sscanf string with brackets ignored", |b| {
         b.iter(|| {
             let mut product: String = String::new();
-            black_box(sscanf!(input, "{{{}}}", product));
+            sscanf!(input, "{{{}}}", product);
             black_box(product);
         })
     });
@@ -94,7 +94,7 @@ fn sscanf_benchmark(c: &mut Criterion) {
         b.iter(|| {
             let mut product: String = String::new();
             let mut price: f64 = 0.0;
-            black_box(sscanf!(input, "{} -> {}", product, price));
+            sscanf!(input, "{} -> {}", product, price);
             black_box(product);
             black_box(price);
         })
@@ -105,7 +105,7 @@ fn sscanf_benchmark(c: &mut Criterion) {
         b.iter(|| {
             let mut first_number: u32 = 0;
             let mut second_number: f64 = 0.0;
-            black_box(sscanf!(input, "{} -> {}", first_number, second_number));
+            sscanf!(input, "{} -> {}", first_number, second_number);
             black_box(first_number);
             black_box(second_number);
         })
